package ${basePackage}.datainit;

import org.junit.Test;
import org.junit.runner.RunWith;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.boot.test.context.SpringBootTest;
import org.springframework.test.annotation.Rollback;
import org.springframework.test.context.junit4.SpringRunner;
import org.springframework.transaction.annotation.Transactional;
import ${basePackage}.frame.auth.Token;
import ${basePackage}.module.system.mgr.DictItemManager;
import ${basePackage}.module.system.mgr.DictManager;
import ${basePackage}.module.system.req.DictCreateRequest;
import ${basePackage}.module.system.req.DictItemCreateRequest;
import ${basePackage}.module.system.rsp.DictCreateResponse;
import ${basePackage}.module.system.rsp.DictItemCreateResponse;

import java.text.SimpleDateFormat;
import java.util.Date;

import static org.junit.Assert.assertTrue;

@RunWith(SpringRunner.class)
@SpringBootTest
@Transactional
public class DictInit {

    @Autowired
    private DictManager dictManager;
    @Autowired
    private DictItemManager dictItemManager;
    @Autowired
    private Token token;

    @Test
    @Rollback(false)
    public void init() {
        {// 终端类型
            createDict("TERMINAL_TYPE", "终端类型", new String[][]{
                    {"WEB", "游览器端"},
                    {"API", "接口端"},
                    {"PHONE", "手机端"},
            });
        }

        {// 错误日志结果
            createDict("LOG_ERR_RESULT", "错误日志结果", new String[][]{
                    {"未处理", "未处理"},
                    {"已处理", "已处理"},
                    {"搁置", "搁置"},
            });
        }

        {// 资源类型
            createDict("RES_TYPE", "资源类型", new String[][]{
                    {"网页地址", "网页地址"},
                    {"异步请求", "异步请求"},
            });
        }
        {// 用户状态
            createDict("USER_STATUS", "用户状态", new String[][]{
                    {"正常", "正常"},
                    {"初始密码", "初始密码"},
                    {"锁定/注销", "锁定/注销"},
            });
        }
        {// 日志错误类型
            createDict("LOG_ERR_TYPE", "日志错误类型", new String[][]{
                    {"系统错误", "系统错误"},
                    {"业务错误", "业务错误"},
            });
        }
    }

    private void createDict(String name, String comment, String[][] items) {
        DictCreateRequest dictCreateRequest = new DictCreateRequest();
        dictCreateRequest.setDictName(name);
        dictCreateRequest.setDictComment(comment);
        dictCreateRequest.setVersion(new SimpleDateFormat("yyyy-MM-dd HH:mm:ss").format(new Date()));
        dictCreateRequest.setValid(true);
        DictCreateResponse dictCreateResponse = dictManager.create(dictCreateRequest, token);
        assertTrue(!dictCreateResponse.hasError());

        for (int i = 0; i < items.length; i++) {
            String[] item = items[i];
            DictItemCreateRequest dictItemCreateRequest = new DictItemCreateRequest();
            dictItemCreateRequest.setDictName(name);
            dictItemCreateRequest.setKey(item[0]);
            dictItemCreateRequest.setValue(item[1]);
            dictItemCreateRequest.setSort(i);
            dictItemCreateRequest.setValid(true);
            DictItemCreateResponse dictItemCreateResponse = dictItemManager.create(dictItemCreateRequest, token);
            assertTrue(!dictItemCreateResponse.hasError());
        }
    }
}

